<?php

function banners_overview_bannersblocks($form) {
  $bannersblocks = banners_get_bannersblocks();
  $form['#tree'] = TRUE;
  foreach ($bannersblocks as $bannersblock) {
    $form[$bannersblock->bid]['#bannersblock'] = $bannersblock;
    $form[$bannersblock->bid]['name'] = array('#markup' => check_plain($bannersblock->name));
    $form[$bannersblock->bid]['weight'] = array(
      '#type' => 'weight',
      '#title' => t('Weight for @title', array('@title' => $bannersblock->name)),
      '#title_display' => 'invisible',
      '#delta' => 10,
      '#default_value' => $bannersblock->weight,
    );
    $form[$bannersblock->bid]['edit'] = array('#type' => 'link', '#title' => t('Edit'), '#href' => "admin/structure/banners/$bannersblock->machine_name/edit");
    $form[$bannersblock->bid]['list'] = array('#type' => 'link', '#title' => t('List items'), '#href' => "admin/structure/banners/$bannersblock->machine_name");
    $form[$bannersblock->bid]['add'] = array('#type' => 'link', '#title' => t('Add items'), '#href' => "admin/structure/banners/$bannersblock->machine_name/add");
  }

  if (count($bannersblocks) > 1) {
    $form['actions'] = array('#type' => 'actions');
    $form['actions']['submit'] = array('#type' => 'submit', '#value' => t('Save'));
  }
  elseif (isset($bannersblock)) {
    unset($form[$bannersblock->bid]['weight']);
  }
  return $form;
}


function banners_overview_bannersblocks_submit($form, &$form_state) {
  foreach ($form_state['values'] as $bid => $bannersblock) {
    if (is_numeric($bid) && $form[$bid]['#bannersblock']->weight != $form_state['values'][$bid]['weight']) {
      $form[$bid]['#bannersblock']->weight = $form_state['values'][$bid]['weight'];
      banners_bannersblock_save($form[$bid]['#bannersblock']);
    }
  }
  drupal_set_message(t('The configuration options have been saved.'));
}


function theme_banners_overview_bannersblocks($variables) {
  $form = $variables['form'];

  $rows = array();

  foreach (element_children($form) as $key) {
    if (isset($form[$key]['name'])) {
      $bannersblock = &$form[$key];

      $row = array();
      $row[] = drupal_render($bannersblock['name']);
      if (isset($bannersblock['weight'])) {
        $bannersblock['weight']['#attributes']['class'] = array('bannersblock-weight');
        $row[] = drupal_render($bannersblock['weight']);
      }
      $row[] = drupal_render($bannersblock['edit']);
      $row[] = drupal_render($bannersblock['list']);
      $row[] = drupal_render($bannersblock['add']);
      $rows[] = array('data' => $row, 'class' => array('draggable'));
    }
  }

  $header = array(t('banners block name'));
  if (isset($form['actions'])) {
    $header[] = t('Weight');
    drupal_add_tabledrag('banners', 'order', 'sibling', 'bannersblock-weight');
  }
  $header[] = array('data' => t('Operations'), 'colspan' => '3');
  return theme('table', array('header' => $header, 'rows' => $rows, 'empty' => t('No banners blocks available. <a href="@link">Add banners block</a>.', array('@link' => url('admin/structure/banners/add'))), 'attributes' => array('id' => 'banners'))) . drupal_render_children($form);
}

function banners_load_struct_menu ($menu_item, $count, &$kq) {
  $result = array();
  $kq[0] = t('<None>');
  foreach ($menu_item as $key_menu_item => $value_menu_item) {
    $result[$value_menu_item['link']['link_title']] = $value_menu_item['link']['link_title'];

    $str_temp = '';
    for ($i=0; $i < $count; $i++) { 
      $str_temp .= '----';
    }

    $kq[$value_menu_item['link']['mlid']] = $str_temp . $value_menu_item['link']['link_title'];
    if (!empty($value_menu_item['below'])) {
      $bellow_item = $value_menu_item['below'];
      $result[$value_menu_item['link']['link_title']] = banners_load_struct_menu($bellow_item, $count + 1, $kq);
    }
  }

  return $result;
}

function banners_form_item($form, &$form_state, $edit = array(), $bannersblock = NULL) {
  $menu_item = menu_tree_all_data('main-menu');
  $list_menu = array();
  banners_load_struct_menu($menu_item, 0, $list_menu);
  
  if (!isset($form_state['item'])) {
    $item = is_object($edit) ? $edit : (object) $edit;
    if (!isset($bannersblock) && isset($item->bid)) {
      $bannersblock = banners_bannersblock_load($item->bid);
    }
    $defaults = array(
      'name' => '',
      'description' => '',
      'format' => NULL,
      'bannersblock_machine_name' => isset($bannersblock) ? $bannersblock->machine_name : NULL,
      'iid' => NULL,
      'weight' => 0,
    );
    foreach ($defaults as $key => $value) {
      if (!isset($item->$key)) {
        $item->$key = $value;
      }
    }
    $form_state['item'] = $item;
  }
  else {
    $item = $form_state['item'];
    if (!isset($bannersblock) && isset($item->bid)) {
      $bannersblock = banners_bannersblock_load($item->bid);
    }
  }

  $parent = array_keys(banners_get_parents($item->iid));
  $form['#item'] = (array) $item;
  $form['#item']['parent'] = $parent;
  $form['#bannersblock'] = $bannersblock;

  // Check for confirmation forms.
  if (isset($form_state['confirm_delete'])) {
    return array_merge($form, banners_item_confirm_delete($form, $form_state, $item->iid));
  }

  $form['menu_item'] = array(
    '#weight' => '1',
    '#key_type' => 'associative',
    '#multiple_toggle' => '1',
    '#type' => 'select',
    '#options' => $list_menu,
    '#title' => 'Display menu',
    '#default_value' => isset($item->menu_item) ? $item->menu_item : '',
  );
  $form['picture'] = array(
    '#type' => 'managed_file',
    '#title' => t('Picture'),
    '#description' => t('Allowed extensions: gif png jpg jpeg'),
    '#upload_location' => 'public://banners/',
    '#default_value' => isset($item->picture) ? $item->picture : '',
    '#upload_validators' => array(
      'file_validate_extensions' => array('gif png jpg jpeg'),
    ),
  );
  $form['paths'] = array(
    '#type' => 'textfield',
    '#title' => t('Paths'),
    '#default_value' => isset($item->paths) ? $item->paths : '',
    '#maxlength' => 255,
    '#required' => FALSE,
    '#weight' => -5,
  );
  $form['url'] = array(
    '#type' => 'textfield',
    '#title' => t('Url (href link)'),
    '#default_value' => isset($item->url) ? $item->url : '',
    '#maxlength' => 255,
    '#required' => FALSE,
    '#weight' => -5,
  );
  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#default_value' => isset($item->name) ? $item->name : '',
    '#maxlength' => 255,
    '#required' => FALSE,
    '#weight' => -5,
  );
  

  $form['bannersblock_machine_name'] = array(
    '#type' => 'value',
    '#value' => isset($item->bannersblock_machine_name) ? $item->bannersblock_machine_name : $bannersblock->name,
  );

  $langcode = entity_language('banners_item', $item);
  field_attach_form('banners_item', $item, $form, $form_state, $langcode);

  $form['relations'] = array(
    '#type' => 'fieldset',
    '#title' => t('Relations'),
    '#collapsible' => TRUE,
    '#collapsed' => $bannersblock->hierarchy < 2,
    '#weight' => 10,
  );

  if (!variable_get('banners_override_selector', FALSE)) {
    $parent = array_keys(banners_get_parents($item->iid));
    $children = banners_get_tree($bannersblock->bid, $item->iid);

    // A item can't be the child of itself, nor of its children.
    foreach ($children as $child) {
      $exclude[] = $child->iid;
    }
    $exclude[] = $item->iid;

    $tree = banners_get_tree($bannersblock->bid);
    $options = array('<' . t('root') . '>');
    if (empty($parent)) {
      $parent = array(0);
    }
    foreach ($tree as $iitem) {
      if (!in_array($iitem->iid, $exclude)) {
        $options[$iitem->iid] = str_repeat('-', $iitem->depth) . $iitem->name;
      }
    }
    $form['relations']['parent'] = array(
      '#type' => 'select',
      '#title' => t('Parent items'),
      '#options' => $options,
      '#default_value' => $parent,
      '#multiple' => TRUE,
    );

  }

  $form['relations']['weight'] = array(
    '#type' => 'textfield',
    '#title' => t('Weight'),
    '#size' => 6,
    '#default_value' => $item->weight,
    '#description' => t('items are displayed in ascending order by weight.'),
    '#required' => TRUE,
  );
  $form['bid'] = array(
    '#type' => 'value',
    '#value' => $bannersblock->bid,
  );
  $form['iid'] = array(
    '#type' => 'value',
    '#value' => $item->iid,
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#weight' => 5,
  );

  if ($item->iid) {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#access' => user_access("delete items in $bannersblock->bid") || user_access('administer banners'),
      '#weight' => 10,
    );
  }
  else {
    $form_state['redirect'] = $_GET['q'];
  }

  return $form;
}

function banners_form_item_validate($form, &$form_state) {
  entity_form_field_validate('banners_item', $form, $form_state);

  // Ensure numeric values.
  if (isset($form_state['values']['weight']) && !is_numeric($form_state['values']['weight'])) {
    form_set_error('weight', t('Weight value must be numeric.'));
  }
}

function banners_form_item_submit($form, &$form_state) {
  # Upload image
  $image_fid = $form_state['values']['picture'];
  $image = file_load($image_fid);
  if (is_object($image)) {
    // Check to make sure that the file is set to be permanent.
    if ($image->status == 0) {
      // Update the status.
      $image->status = FILE_STATUS_PERMANENT;
      // Save the update.
      file_save($image);
      // Add a reference to prevent warnings.
      file_usage_add($image, 'banners', 'banners', 1);
     }
  }

  if ($form_state['triggering_element']['#value'] == t('Delete')) {
    if ($form_state['values']['delete'] === TRUE) {
      return banners_item_confirm_delete_submit($form, $form_state);
    }
    $form_state['rebuild'] = TRUE;
    $form_state['confirm_delete'] = TRUE;
    return;
  }

  $item = banners_form_item_submit_build_banners_item($form, $form_state);
  $status = banners_item_save($item);
  switch ($status) {
    case SAVED_NEW:
      drupal_set_message(t('Created new item %item.', array('%item' => $item->name)));
      watchdog('banners', 'Created new item %item.', array('%item' => $item->name), WATCHDOG_NOTICE, l(t('edit'), 'banners/item/' . $item->iid . '/edit'));
      break;
    case SAVED_UPDATED:
      drupal_set_message(t('Updated item %item.', array('%item' => $item->name)));
      watchdog('banners', 'Updated item %item.', array('%item' => $item->name), WATCHDOG_NOTICE, l(t('edit'), 'banners/item/' . $item->iid . '/edit'));
      cache_clear_all();
      break;
  }

  $current_parent_count = count($form_state['values']['parent']);
  $previous_parent_count = count($form['#item']['parent']);
  if ($current_parent_count == 1 && isset($form_state['values']['parent'][0])) {
    $current_parent_count = 0;
    $form_state['values']['parent'] = array();
  }

  if ($current_parent_count < $previous_parent_count && $current_parent_count < 2) {
    banners_check_bannersblock_hierarchy($form['#bannersblock'], $form_state['values']);
  }

  elseif ($current_parent_count > $previous_parent_count && $form['#bannersblock']->hierarchy < 2) {
    $form['#bannersblock']->hierarchy = $current_parent_count == 1 ? 1 : 2;
    banners_bannersblock_save($form['#bannersblock']);
  }

  $form_state['values']['iid'] = $item->iid;
  $form_state['iid'] = $item->iid;
}

function banners_form_item_submit_build_banners_item($form, &$form_state) {
  $item = $form_state['item'];
  entity_form_submit_build_entity('banners_item', $item, $form, $form_state);
  return $item;
}

function banners_item_confirm_delete($form, &$form_state, $iid) {
  $item = banners_item_load($iid);
  $form['iid'] = array('#type' => 'value', '#value' => $iid);

  $form['#item'] = $item;
  $form['type'] = array('#type' => 'value', '#value' => 'item');
  $form['name'] = array('#type' => 'value', '#value' => $item->name);
  $form['bannersblock_machine_name'] = array('#type' => 'value', '#value' => $item->bannersblock_machine_name);
  $form['delete'] = array('#type' => 'value', '#value' => TRUE);
  return confirm_form($form,
    t('Are you sure you want to delete the item %title?',
    array('%title' => $item->name)),
    'admin/structure/banners',
    t('Deleting a item will delete all its children if there are any. This action cannot be undone.'),
    t('Delete'),
    t('Cancel'));
}

function banners_form_bannersblock($form, &$form_state, $edit = array()) {
  if (!isset($form_state['bannersblock'])) {
    $bannersblock = is_object($edit) ? $edit : (object) $edit;
    $defaults = array(
      'name' => '',
      'machine_name' => '',
      'description' => '',
      'hierarchy' => 0,
      'weight' => 0,
    );
    foreach ($defaults as $key => $value) {
      if (!isset($bannersblock->$key)) {
        $bannersblock->$key = $value;
      }
    }
    $form_state['bannersblock'] = $bannersblock;
  }
  else {
    $bannersblock = $form_state['bannersblock'];
  }

  $form['#bannersblock'] = $form_state['bannersblock'];

  if (isset($form_state['confirm_delete']) && isset($form_state['values']['bid'])) {
    return banners_bannersblock_confirm_delete($form, $form_state, $form_state['values']['bid']);
  }
  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#default_value' => $bannersblock->name,
    '#maxlength' => 255,
    '#required' => TRUE,
  );
  $form['machine_name'] = array(
    '#type' => 'machine_name',
    '#default_value' => $bannersblock->machine_name,
    '#maxlength' => 255,
    '#machine_name' => array(
      'exists' => 'banners_bannersblock_machine_name_load',
    ),
  );
  $form['old_machine_name'] = array(
    '#type' => 'value',
    '#value' => $bannersblock->machine_name,
  );
  $form['description'] = array(
    '#type' => 'textfield',
    '#title' => t('Description'),
    '#default_value' => $bannersblock->description,
  );

  $form['hierarchy'] = array(
    '#type' => 'value',
    '#value' => '0',
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array('#type' => 'submit', '#value' => t('Save'));
  if (isset($bannersblock->bid)) {
    $form['actions']['delete'] = array('#type' => 'submit', '#value' => t('Delete'));
    $form['bid'] = array('#type' => 'value', '#value' => $bannersblock->bid);
    $form['module'] = array('#type' => 'value', '#value' => $bannersblock->module);
  }
  $form['#validate'][] = 'banners_form_bannersblock_validate';

  return $form;
}

function banners_form_bannersblock_validate($form, &$form_state) {
  if (isset($form_state['values']['machine_name'])) {
    $machine_name = $form_state['values']['machine_name'];
    $disallowed = array('add', 'list');
    if (in_array($machine_name, $disallowed)) {
      form_set_error('machine_name', t('The machine-readable name cannot be "add" or "list".'));
    }
  }
}

function banners_form_bannersblock_submit($form, &$form_state) {
  if ($form_state['triggering_element']['#value'] == t('Delete')) {
    $form_state['rebuild'] = TRUE;
    $form_state['confirm_delete'] = TRUE;
    return;
  }

  $bannersblock = $form_state['bannersblock'];
  entity_form_submit_build_entity('banners_bannersblock', $bannersblock, $form, $form_state);

  switch (banners_bannersblock_save($bannersblock)) {
    case SAVED_NEW:
      drupal_set_message(t('Created new bannersblock %name.', array('%name' => $bannersblock->name)));
      watchdog('banners', 'Created new bannersblock %name.', array('%name' => $bannersblock->name), WATCHDOG_NOTICE, l(t('edit'), 'admin/structure/banners/' . $bannersblock->machine_name . '/edit'));
      break;

    case SAVED_UPDATED:
      drupal_set_message(t('Updated bannersblock %name.', array('%name' => $bannersblock->name)));
      watchdog('banners', 'Updated bannersblock %name.', array('%name' => $bannersblock->name), WATCHDOG_NOTICE, l(t('edit'), 'admin/structure/banners/' . $bannersblock->machine_name . '/edit'));
      break;
  }

  $form_state['values']['bid'] = $bannersblock->bid;
  $form_state['bid'] = $bannersblock->bid;
  $form_state['redirect'] = 'admin/structure/banners';
}

function banners_overview_items($form, &$form_state, $bannersblock) {
  global $pager_page_array, $pager_total, $pager_total_items;

  if (isset($form_state['confirm_reset_alphabetical'])) {
    return banners_bannersblock_confirm_reset_alphabetical($form, $form_state, $bannersblock->bid);
  }

  $form['#bannersblock'] = $bannersblock;
  $form['#tree'] = TRUE;
  $form['#parent_fields'] = FALSE;

  $page            = isset($_GET['page']) ? $_GET['page'] : 0;
  $page_increment  = variable_get('banners_items_per_page_admin', 100);  // Number of items per page.
  $page_entries    = 0;   // Elements shown on this page.
  $before_entries  = 0;   // Elements at the root level before this page.
  $after_entries   = 0;   // Elements at the root level after this page.
  $root_entries    = 0;   // Elements at the root level on this page.

  // items from previous and next pages are shown if the item tree would have
  // been cut in the middle. Keep track of how many extra items we show on each
  // page of items.
  $back_step    = NULL;
  $forward_step = 0;

  // An array of the items to be displayed on this page.
  $current_page = array();

  $delta = 0;
  $item_deltas = array();
  $tree = banners_get_tree($bannersblock->bid);
  $item = current($tree);
  do {
    // In case this tree is completely empty.
    if (empty($item)) {
      break;
    }
    $delta++;
    // Count entries before the current page.
    if ($page && ($page * $page_increment) > $before_entries && !isset($back_step)) {
      $before_entries++;
      continue;
    }
    // Count entries after the current page.
    elseif ($page_entries > $page_increment && isset($complete_tree)) {
      $after_entries++;
      continue;
    }

    // Do not let a item start the page that is not at the root.
    if (isset($item->depth) && ($item->depth > 0) && !isset($back_step)) {
      $back_step = 0;
      while ($pitem = prev($tree)) {
        $before_entries--;
        $back_step++;
        if ($pitem->depth == 0) {
          prev($tree);
          continue 2; // Jump back to the start of the root level parent.
       }
      }
    }
    $back_step = isset($back_step) ? $back_step : 0;

    // Continue rendering the tree until we reach the a new root item.
    if ($page_entries >= $page_increment + $back_step + 1 && $item->depth == 0 && $root_entries > 1) {
      $complete_tree = TRUE;
      // This new item at the root level is the first item on the next page.
      $after_entries++;
      continue;
    }
    if ($page_entries >= $page_increment + $back_step) {
      $forward_step++;
    }

    // Finally, if we've gotten down this far, we're rendering a item on this page.
    $page_entries++;
    $item_deltas[$item->iid] = isset($item_deltas[$item->iid]) ? $item_deltas[$item->iid] + 1 : 0;
    $key = 'iid:' . $item->iid . ':' . $item_deltas[$item->iid];

    // Keep track of the first item displayed on this page.
    if ($page_entries == 1) {
      $form['#first_iid'] = $item->iid;
    }
    // Keep a variable to make sure at least 2 root elements are displayed.
    if ($item->parents[0] == 0) {
      $root_entries++;
    }
    $current_page[$key] = $item;
  } while ($item = next($tree));

  // Because we didn't use a pager query, set the necessary pager variables.
  $total_entries = $before_entries + $page_entries + $after_entries;
  $pager_total_items[0] = $total_entries;
  $pager_page_array[0] = $page;
  $pager_total[0] = ceil($total_entries / $page_increment);

  // If this form was already submitted once, it's probably hit a validation
  // error. Ensure the form is rebuilt in the same order as the user submitted.
  if (!empty($form_state['input'])) {
    $order = array_flip(array_keys($form_state['input'])); // Get the $_POST order.
    $current_page = array_merge($order, $current_page); // Update our form with the new order.
    foreach ($current_page as $key => $item) {
      // Verify this is a item for the current page and set at the current depth.
      if (is_array($form_state['input'][$key]) && is_numeric($form_state['input'][$key]['iid'])) {
        $current_page[$key]->depth = $form_state['input'][$key]['depth'];
      }
      else {
        unset($current_page[$key]);
      }
    }
  }

  // Build the actual form.
  foreach ($current_page as $key => $item) {
    // Save the item for the current page so we don't have to load it a second time.
    $form[$key]['#item'] = (array) $item;
    if (isset($item->parents)) {
      $form[$key]['#item']['parent'] = $item->parent = $item->parents[0];
      unset($form[$key]['#item']['parents'], $item->parents);
    }

    $form[$key]['view'] = array('#type' => 'link', '#title' => $item->name, '#href' => "banners/item/$item->iid");
    if ($bannersblock->hierarchy < 2 && count($tree) > 1) {
      $form['#parent_fields'] = TRUE;
      $form[$key]['iid'] = array(
        '#type' => 'hidden',
        '#value' => $item->iid
      );
      $form[$key]['parent'] = array(
        '#type' => 'hidden',
        // Yes, default_value on a hidden. It needs to be changeable by the javascript.
        '#default_value' => $item->parent,
      );
      $form[$key]['depth'] = array(
        '#type' => 'hidden',
        // Same as above, the depth is modified by javascript, so it's a default_value.
        '#default_value' => $item->depth,
      );
      /*
      $form[$key]['weight'] = array(
        '#type' => 'weight',
        '#delta' => $delta,
        '#title_display' => 'invisible',
        '#title' => t('Weight for added item'),
        '#default_value' => $item->weight,
      );*/
    }
    $form[$key]['edit'] = array('#type' => 'link', '#title' => t('edit'), '#href' => 'banners/item/' . $item->iid . '/edit', '#options' => array('query' => drupal_get_destination()));
  }

  $form['#total_entries'] = $total_entries;
  $form['#page_increment'] = $page_increment;
  $form['#page_entries'] = $page_entries;
  $form['#back_step'] = $back_step;
  $form['#forward_step'] = $forward_step;
  $form['#empty_text'] = t('No items available. <a href="@link">Add item</a>.', array('@link' => url('admin/structure/banners/' . $bannersblock->machine_name . '/add')));
  /*
  if ($bannersblock->hierarchy < 2 && count($tree) > 1) {
    $form['actions'] = array('#type' => 'actions', '#tree' => FALSE);
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save')
    );
    $form['actions']['reset_alphabetical'] = array(
      '#type' => 'submit',
      '#value' => t('Reset to alphabetical')
    );
    $form_state['redirect'] = array($_GET['q'], (isset($_GET['page']) ? array('query' => array('page' => $_GET['page'])) : array()));
  }*/

  return $form;
}

function banners_overview_items_submit($form, &$form_state) {
  if ($form_state['triggering_element']['#value'] == t('Reset to alphabetical')) {
    if ($form_state['values']['reset_alphabetical'] === TRUE) {
      return banners_bannersblock_confirm_reset_alphabetical_submit($form, $form_state);
    }

    $form_state['rebuild'] = TRUE;
    $form_state['confirm_reset_alphabetical'] = TRUE;
    return;
  }

  uasort($form_state['values'], 'drupal_sort_weight');

  $bannersblock = $form['#bannersblock'];
  $hierarchy = 0; // Update the current hierarchy type as we go.

  $changed_items = array();
  $tree = banners_get_tree($bannersblock->bid);

  if (empty($tree)) {
    return;
  }

  $weight = 0;
  $item = (array) $tree[0];
  while ($item['iid'] != $form['#first_iid']) {
    if ($item['parents'][0] == 0 && $item['weight'] != $weight) {
      $item['parent'] = $item['parents'][0];
      $item['weight'] = $weight;
      $changed_items[$item['iid']] = $item;
    }
    $weight++;
    $hierarchy = $item['parents'][0] != 0 ? 1 : $hierarchy;
    $item = (array) $tree[$weight];
  }

  // Renumber the current page weights and assign any new parents.
  $level_weights = array();
  foreach ($form_state['values'] as $iid => $values) {
    if (isset($form[$iid]['#item'])) {
      $item = $form[$iid]['#item'];
      // Give items at the root level a weight in sequence with items on previous pages.
      if ($values['parent'] == 0 && $item['weight'] != $weight) {
        $item['weight'] = $weight;
        $changed_items[$item['iid']] = $item;
      }
      // items not at the root level can safely start from 0 because they're all on this page.
      elseif ($values['parent'] > 0) {
        $level_weights[$values['parent']] = isset($level_weights[$values['parent']]) ? $level_weights[$values['parent']] + 1 : 0;
        if ($level_weights[$values['parent']] != $item['weight']) {
          $item['weight'] = $level_weights[$values['parent']];
          $changed_items[$item['iid']] = $item;
        }
      }
      // Update any changed parents.
      if ($values['parent'] != $item['parent']) {
        $item['parent'] = $values['parent'];
        $changed_items[$item['iid']] = $item;
      }
      $hierarchy = $item['parent'] != 0 ? 1 : $hierarchy;
      $weight++;
    }
  }

  // Build a list of all items that need to be updated on following pages.
  for ($weight; $weight < count($tree); $weight++) {
    $item = (array) $tree[$weight];
    if ($item['parents'][0] == 0 && $item['weight'] != $weight) {
      $item['parent'] = $item['parents'][0];
      $item['weight'] = $weight;
      $changed_items[$item['iid']] = $item;
    }
    $hierarchy = $item['parents'][0] != 0 ? 1 : $hierarchy;
  }

  // Save all updated items.
  foreach ($changed_items as $changed) {
    $item = (object) $changed;
    // Update item_hierachy and item_data directly since we don't have a
    // fully populated item object to save.
    db_update('banners_item_hierarchy')
      ->fields(array('parent' => $item->parent))
      ->condition('iid', $item->iid, '=')
      ->execute();

    db_update('banners_item_data')
      ->fields(array('weight' => $item->weight))
      ->condition('iid', $item->iid, '=')
      ->execute();
  }

  // Update the bannersblock hierarchy to flat or single hierarchy.
  if ($bannersblock->hierarchy != $hierarchy) {
    $bannersblock->hierarchy = $hierarchy;
    banners_bannersblock_save($bannersblock);
  }
  drupal_set_message(t('The configuration options have been saved.'));
}

function theme_banners_overview_items($variables) {

  $form = $variables['form'];

  $page_increment  = $form['#page_increment'];
  $page_entries    = $form['#page_entries'];
  $back_step     = $form['#back_step'];
  $forward_step  = $form['#forward_step'];

  /*if ($form['#parent_fields']) {
    drupal_add_tabledrag('banners', 'match', 'parent', 'item-parent', 'item-parent', 'item-id', FALSE);
    drupal_add_tabledrag('banners', 'depth', 'group', 'item-depth', NULL, NULL, FALSE);
    drupal_add_js(drupal_get_path('module', 'banners') . '/js/banners.js');
    drupal_add_js(array('banners' => array('backStep' => $back_step, 'forwardStep' => $forward_step)), 'setting');
    drupal_add_css(drupal_get_path('module', 'banners') . '/css/banners.css');
  }*/
  //drupal_add_tabledrag('banners', 'order', 'sibling', 'item-weight');

  $errors = form_get_errors() != FALSE ? form_get_errors() : array();
  $rows = array();
  foreach (element_children($form) as $key) {
    if (isset($form[$key]['#item'])) {
      $item = &$form[$key];
      $row = array();
      $row[] = (isset($item['#item']['depth']) && $item['#item']['depth'] > 0 ? theme('indentation', array('size' => $item['#item']['depth'])) : ''). drupal_render($item['view']);
      if ($form['#parent_fields']) {
        $item['iid']['#attributes']['class'] = array('item-id');
        $item['parent']['#attributes']['class'] = array('item-parent');
        $item['depth']['#attributes']['class'] = array('item-depth');
        $row[0] .= drupal_render($item['parent']) . drupal_render($item['iid']) . drupal_render($item['depth']);
      }
      $item['weight']['#attributes']['class'] = array('item-weight');
      //$row[] = drupal_render($item['weight']);
      $row[] = l(t('/' . $item['#item']['paths']), $item['#item']['paths'], array('attributes' => array('name' => 'name-of-anchor')));
      $row[] = drupal_render($item['edit']);
      $row = array('data' => $row);
      $rows[$key] = $row;
    }
  }

  // Add necessary classes to rows.
  $row_position = 0;
  foreach ($rows as $key => $row) {
    $rows[$key]['class'] = array();
    if (isset($form['#parent_fields'])) {
      $rows[$key]['class'][] = 'draggable';
    }

    // Add classes that mark which items belong to previous and next pages.
    if ($row_position < $back_step || $row_position >= $page_entries - $forward_step) {
      $rows[$key]['class'][] = 'banners-item-preview';
    }

    if ($row_position !== 0 && $row_position !== count($rows) - 1) {
      if ($row_position == $back_step - 1 || $row_position == $page_entries - $forward_step - 1) {
        $rows[$key]['class'][] = 'banners-item-dibider-top';
      }
      elseif ($row_position == $back_step || $row_position == $page_entries - $forward_step) {
        $rows[$key]['class'][] = 'banners-item-dibider-bottom';
      }
    }

    // Add an error class if this row contains a form error.
    foreach ($errors as $error_key => $error) {
      if (strpos($error_key, $key) === 0) {
        $rows[$key]['class'][] = 'error';
      }
    }
    $row_position++;
  }

  if (empty($rows)) {
    $rows[] = array(array('data' => $form['#empty_text'], 'colspan' => '3'));
  }

  $header = array(t('Name'), t('Paths'), t('Operations'));
  $output = theme('table', array('header' => $header, 'rows' => $rows, 'attributes' => array('id' => 'banners')));
  $output .= drupal_render_children($form);
  $output .= theme('pager');

  return $output;
}

function banners_item_confirm_delete_submit($form, &$form_state) {
  banners_item_delete($form_state['values']['iid']);
  banners_check_bannersblock_hierarchy($form['#bannersblock'], $form_state['values']);
  drupal_set_message(t('Deleted item %name.', array('%name' => $form_state['values']['name'])));
  watchdog('banners', 'Deleted item %name.', array('%name' => $form_state['values']['name']), WATCHDOG_NOTICE);
  $form_state['redirect'] = 'admin/structure/banners';
  cache_clear_all();
  return;
}

function banners_bannersblock_confirm_delete($form, &$form_state, $bid) {
  $bannersblock = banners_bannersblock_load($bid);

  // Always probide entity id in the same form key as in the entity edit form.
  $form['bid'] = array('#type' => 'value', '#value' => $bid);

  $form['#bannersblock'] = $bannersblock;
  $form['#id'] = 'banners_bannersblock_confirm_delete';
  $form['type'] = array('#type' => 'value', '#value' => 'bannersblock');
  $form['name'] = array('#type' => 'value', '#value' => $bannersblock->name);
  $form['#submit'] = array('banners_bannersblock_confirm_delete_submit');
  return confirm_form($form,
    t('Are you sure you want to delete the bannersblock %title?',
    array('%title' => $bannersblock->name)),
    'admin/structure/banners',
    t('Deleting a bannersblock will delete all the items in it. This action cannot be undone.'),
    t('Delete'),
    t('Cancel'));
}

function banners_bannersblock_confirm_delete_submit($form, &$form_state) {
  $status = banners_bannersblock_delete($form_state['values']['bid']);
  drupal_set_message(t('Deleted bannersblock %name.', array('%name' => $form_state['values']['name'])));
  watchdog('banners', 'Deleted bannersblock %name.', array('%name' => $form_state['values']['name']), WATCHDOG_NOTICE);
  $form_state['redirect'] = 'admin/structure/banners';
  cache_clear_all();
  return;
}

function banners_bannersblock_confirm_reset_alphabetical($form, &$form_state, $bid) {
  $bannersblock = banners_bannersblock_load($bid);

  $form['type'] = array('#type' => 'value', '#value' => 'bannersblock');
  $form['bid'] = array('#type' => 'value', '#value' => $bid);
  $form['machine_name'] = array('#type' => 'value', '#value' => $bannersblock->machine_name);
  $form['name'] = array('#type' => 'value', '#value' => $bannersblock->name);
  $form['reset_alphabetical'] = array('#type' => 'value', '#value' => TRUE);
  return confirm_form($form,
                  t('Are you sure you want to reset the bannersblock %title to alphabetical order?',
                  array('%title' => $bannersblock->name)),
                  'admin/structure/banners/' . $bannersblock->machine_name,
                  t('Resetting a bannersblock will discard all custom ordering and sort items alphabetically.'),
                  t('Reset to alphabetical'),
                  t('Cancel'));
}

function banners_bannersblock_confirm_reset_alphabetical_submit($form, &$form_state) {
  db_update('banners_item_data')
    ->fields(array('weight' => 0))
    ->condition('bid', $form_state['values']['bid'])
    ->execute();
  drupal_set_message(t('Reset bannersblock %name to alphabetical order.', array('%name' => $form_state['values']['name'])));
  watchdog('banners', 'Reset bannersblock %name to alphabetical order.', array('%name' => $form_state['values']['name']), WATCHDOG_NOTICE);
  $form_state['redirect'] = 'admin/structure/banners/' . $form_state['values']['machine_name'];
}
