<?php

/**
 * @file
 * Educational's theme implementation for template functions
 */

include_once drupal_get_path('theme', 'educational') . '/common.inc';

/**
 * Hook theme.
 */
function educational_theme() {
  $items = array();
  $items['render_panel'] = array(
    "variables" => array(
      'page' => array(),
      'panels_list' => array(),
      'panel_regions_width' => array(),
    ),
    'preprocess functions' => array(
      'educational_preprocess_render_panel',
    ),
    'template' => 'panel',
    'path' => drupal_get_path('theme', 'educational') . '/tpl',
  );
  return $items;
}

/**
 * Hook preprocess html.
 */
function educational_preprocess_html(&$vars) {
  $animation = 'animation-' . theme_get_setting('animation');
  $vars['classes_array'][] = $animation;
  $vars['classes'] = ' ';

  $current_skin = theme_get_setting('skin');
  if (isset($_COOKIE['weebpal_skin'])) {
    $current_skin = $_COOKIE['weebpal_skin'];
  }

  if (!empty($current_skin) && $current_skin != 'default') {
    $vars['classes'] .= " skin-$current_skin";
  }

  $current_background = theme_get_setting('background');
  if (isset($_COOKIE['weebpal_background'])) {
    $current_background = $_COOKIE['weebpal_background'];
  }

  if (isset($current_background) && !empty($current_background)) {
    $vars['classes'] .= (' ' . $current_background);
  }
}

/**
 * Hook preprocess page.
 */
function educational_preprocess_page(&$vars) {
  $vars['page_css'] = '';
  global $theme_key;
  $vars['regions_width'] = educational_regions_width($vars['page']);
  $panel_regions = educational_panel_regions();
  
  if (count($panel_regions)) {
    foreach ($panel_regions as $panel_name => $panels_list) {
      $panel_markup = theme("render_panel", array(
        'page' => $vars['page'],
        'panels_list' => $panels_list,
        'regions_width' => $vars['regions_width'],
      ));
      $panel_markup = trim($panel_markup);
      $vars['page'][$panel_name] = empty($panel_markup) ? FALSE : array('content' => array('#markup' => $panel_markup));
    }
  }

  $current_skin = theme_get_setting('skin');
  if (isset($_COOKIE['weebpal_skin'])) {
    $current_skin = $_COOKIE['weebpal_skin'];
  }

  $layout_width = (theme_get_setting('layout_width') == '')
                  ? theme_get_setting('layout_width_default')
                  : theme_get_setting('layout_width');
  $vars['page']['show_skins_menu'] = $show_skins_menu = theme_get_setting('show_skins_menu');

  if($show_skins_menu) {
    $current_layout = theme_get_setting('layout');
    if (isset($_COOKIE['weebpal_layout'])) {
      $current_layout = $_COOKIE['weebpal_layout'];
    }

    if ($current_layout == 'layout-boxed') {
      $vars['page_css'] = 'style="max-width:' . $layout_width . 'px;margin: 0 auto;" class="boxed"';
    }

    $data = array(
      'layout_width' => $layout_width,
      'current_layout' => $current_layout
    );
    $skins_menu = theme_render_template(drupal_get_path('theme', 'educational') . '/tpl/skins-menu.tpl.php', $data);
    $vars['page']['show_skins_menu'] = $skins_menu;
  }

  
  $vars['page']['weebpal_skin_classes'] = !empty($current_skin) ? ($current_skin . "-skin") : "";
  if (!empty($current_skin) && $current_skin != 'default' && theme_get_setting("default_logo") && theme_get_setting("toggle_logo")) {
    $vars['logo'] = file_create_url(drupal_get_path('theme', $theme_key)) . "/css/colors/" . $current_skin . "/images/logo.png";
  }

  $skin = theme_get_setting('skin');
  if (isset($_COOKIE['weebpal_skin'])) {
    $skin = $_COOKIE['weebpal_skin'] == 'default' ? '' : $_COOKIE['weebpal_skin'];
  }
  if (!empty($skin)) {
    $pathfile = drupal_get_path('theme', $theme_key) . "/css/colors/" . $skin . "/style.css";
    if (file_exists($pathfile)) {
      drupal_add_css($pathfile, array(
        'group' => CSS_THEME,
      ));
    }
  }
  
  drupal_add_css(drupal_get_path('theme', $theme_key) . "/css/screens/tablet.css", array(
    'media' => 'only screen and (min-width:992px) and (max-width:1199px)',
    'group' => CSS_THEME,
  ));
  drupal_add_css(drupal_get_path('theme', $theme_key) . "/css/screens/common.css", array(
    'media' => 'only screen and (max-width:991px)',
    'group' => CSS_THEME,
  ));
  drupal_add_css(drupal_get_path('theme', $theme_key) . "/css/screens/vertical_tablet.css", array(
    'media' => 'only screen and (min-width:768px) and (max-width:991px)',
    'group' => CSS_THEME,
  ));
  drupal_add_css(drupal_get_path('theme', $theme_key) . "/css/screens/mobile.css", array(
    'media' => 'only screen and (max-width:767px)',
    'group' => CSS_THEME,
  ));
  
  $vars['titlebg'] = theme_get_setting('titlebg');

  $vars['educational_page_slogan'] = false;  
  $vars['educational_node_type'] = false;    
  if(isset($vars['node'])) {
    if(isset($vars['node']->body['und'][0]['summary']) && !empty($vars['node']->body['und'][0]['summary'])) {
      $vars['educational_page_slogan'] = $vars['node']->body['und'][0]['summary'];
    }

    if(isset($vars['node']->type)) {
      $vars['educational_node_type'] = $vars['node']->type; 
    }
  }
  elseif(isset($vars['page'])) {
    if(isset($vars['page']['#views_contextual_links_info']['views_ui']['view']->description)
       && !empty($vars['page']['#views_contextual_links_info']['views_ui']['view']->description)) {
      $vars['educational_page_slogan'] = $vars['page']['#views_contextual_links_info']['views_ui']['view']->description;
    }
  }

}

function educational_preprocess_node(&$vars) {
  if (theme_get_setting('node_animation')) {
    $vars['classes_array'][] = 'animation';
  }

  unset($vars['content']['links']['statistics']['#links']['statistics_counter']['title']);
}

/**
 * Hook preprocess render panel.
 */
function educational_preprocess_render_panel(&$variables) {
  $page = $variables['page'];
  $panels_list = $variables['panels_list'];
  $regions_width = $variables['regions_width'];
  $variables = array();
  $variables['page'] = array();
  $variables['panel_width'] = $regions_width;
  $variables['panel_classes'] = array();
  $variables['panels_list'] = $panels_list;
  $is_empty = TRUE;
  $panel_keys = array_keys($panels_list);

  foreach ($panels_list as $panel) {
    $variables['page'][$panel] = $page[$panel];
    $panel_width = $regions_width[$panel];
    if (render($page[$panel])) {
      $is_empty = FALSE;
    }
    $classes = array("panel-column");
    // $classes[] = "col-lg-$panel_width";
    // $classes[] = "col-md-$panel_width";
    $classes[] = "col-sm-$panel_width";
    // $classes[] = "col-xs-$panel_width";
    $classes[] = str_replace("_", "-", $panel);
    $variables['panel_classes'][$panel] = implode(" ", $classes);
  }
  $variables['empty_panel'] = $is_empty;
}

function educational_form_alter( &$form, &$form_state, $form_id ) {
  if ($form_id == 'search_block_form')
  {
    $form['search_block_form']['#attributes']['placeholder'] = t( 'Enter any terms...' );
  }
}

/**
 * Get predefined param.
 */

function _get_predefined_param($param, $pre_array = array(), $suf_array = array()) {
  global $theme_key;
  $theme_data = list_themes();
  $result = isset($theme_data[$theme_key]->info[$param]) ? $theme_data[$theme_key]->info[$param] : array();
  return $pre_array + $result + $suf_array;
}